'use strict';

const assert = require('assert');
const _ = require('lodash');
const { ObjectId } = require('mongoose').Types;
const { CrudService } = require('naf-framework-mongoose/lib/service');
const company = require('../model/company');
const { BusinessError, ErrorCode } = require('naf-core').Error;

class CompanyService extends CrudService {
  constructor(ctx) {
    super(ctx, 'company');
    this.model = this.ctx.model.Company;
    // this.umodel = this.ctx.model.User;
  }

  async create(data) {
    const { company, engCompany, brief, imagearray } = data;
    assert(company, '企业名称不能为空');
    assert(engCompany, '英文名称不能为空');
    assert(brief, '简介不能为空');
    const user = [];
    for (const elm of company) {
      const n = await this.model.findById(elm);
      if (n) {
        user.push(n);
      }
    }
    data.name = user;
    return await this.model.create(data);
  }

  async delete({ company }) {
    await this.model.findByIdAndDelete(company);
    return 'deleted';
  }

  async update({ company }, data) {
    const { engCompany, brief, imagearray } = data;
    const res = await this.model.findById(company);
    // const res = await this.model.update({ _id: ObjectId(id) }, data);
    if (company) {
      res.name = company;
    }
    if (engCompany) {
      res.engCompany = engCompany;
    }
    if (brief) {
      res.brief = brief;
    }
    if (imagearray) {
      res.imagearray = imagearray;
    }
    return await res.save();
  }

  // 查询
  async query({ name }) {
    const res = await this.model.findByIdAndDelete(name);
    return res;
  }
}

module.exports = CompanyService;
